@@ -106,7 +106,6 @@ public:
         }
 
         SkkServer(const char *identifier, int port, int log_level) :
-                socket_(),
                 syslog_(identifier, log_level),
                 work_(0),
                 port_(port),
@@ -131,7 +130,7 @@ protected:
                 int send_size = 0;
                 for (;;)
                 {
-                        int send_result = socket_.send(file_descriptor, data, data_size);
+                        int send_result = SkkSocket::send(file_descriptor, data, data_size);
                         if (send_result == -1)
                         {
                                 break;
@@ -430,9 +429,9 @@ protected:
         bool main_loop_recv(int work_index, int &recv_result, bool &error_break_flag)
         {
                 bool result = true;
-                recv_result = socket_.receive((work_ + work_index)->file_descriptor,
-                                              (work_ + work_index)->read_buffer + (work_ + work_index)->read_process_index,
-                                              MIDASI_SIZE + MIDASI_TERMINATOR_SIZE - (work_ + work_index)->read_process_index);
+                recv_result = SkkSocket::receive((work_ + work_index)->file_descriptor,
+                                                 (work_ + work_index)->read_buffer + (work_ + work_index)->read_process_index,
+                                                 MIDASI_SIZE + MIDASI_TERMINATOR_SIZE - (work_ + work_index)->read_process_index);
                 error_break_flag = false;
                 if (recv_result == -1)
                 {
@@ -670,7 +669,6 @@ protected:
                 bool flag;
         };
 
-        SkkSocket socket_;
         SkkSyslog syslog_;
         Work *work_;
         int port_;
