@@ -46,6 +46,7 @@ public:
         }
 
         GoogleJapaneseInput() :
+                skk_socket_(),
                 work_a_buffer_size_(4 * 1024),
                 work_b_buffer_size_(4 * 1024),
                 http_send_buffer_size_(4 * 1024),
@@ -305,36 +306,11 @@ private:
                 http_send_string_.append(url_encode_word);
                 http_send_string_.append(",\x0d\x0a\x0d\x0a");
 
-                struct hostent *hostent = gethostbyname("www.google.com");
-                if (hostent == 0)
-                {
-                        return false;
-                }
-                struct sockaddr_in sockaddr;
-                memset(&sockaddr, 0, sizeof(sockaddr));
-                sockaddr.sin_family = AF_INET;
-                memcpy(&sockaddr.sin_addr, hostent->h_addr, hostent->h_length);
-                struct servent *service = getservbyname("http", "tcp");
-                if (service == 0)
-                {
-                        return false;
-                }
-                sockaddr.sin_port = static_cast<in_port_t>(service->s_port);
-                int socket_fd = socket(AF_INET, SOCK_STREAM, 0);
-                if (socket_fd < 0)
-                {
-                        return false;
-                }
-                bool result = true;
-                if (connect(socket_fd, reinterpret_cast<struct sockaddr*>(&sockaddr), sizeof(sockaddr)) == -1)
-                {
-                        result = false;
-                }
-                fcntl(socket_fd, F_SETFL, O_NONBLOCK);
+                int socket_fd = skk_socket_.prepareASyncSocket("www.google.com", timeout);
+                bool result = socket_fd >= 0;
                 if (result)
                 {
-                        SkkSocket skk_socket;
-                        int send_result = skk_socket.send(socket_fd, http_send_string_.getBuffer(), http_send_string_.getSize());
+                        int send_result = SkkSocket::send(socket_fd, http_send_string_.getBuffer(), http_send_string_.getSize());
                         if (send_result == -1)
                         {
                                 if ((errno != EAGAIN) && (errno != EWOULDBLOCK))
@@ -348,13 +324,16 @@ private:
                                 SkkUtility::WaitAndCheckForGoogleJapaneseInput wait_and_check_for_google_japanese_input;
                                 for (;;)
                                 {
+                                        // select() ǤϤʤݡ󥰤ǥ롼׽Ƥ뤳ȤդɬפǤ
+                                        //  receive() λ֤⥿ॢȤȤƹθ뤿Ǥ
+                                        // (ޤºݤˤϤޤѤʤϤǤ)
                                         if (!wait_and_check_for_google_japanese_input.waitAndCheckLoopHead(timeout))
                                         {
                                                 result = false;
                                                 break;
                                         }
                                         const int margin = 256;
-                                        int receive_size = skk_socket.receive(socket_fd, http_receive_buffer_ + receive_buffer_index, http_receive_buffer_size_ - receive_buffer_index - margin);
+                                        int receive_size = SkkSocket::receive(socket_fd, http_receive_buffer_ + receive_buffer_index, http_receive_buffer_size_ - receive_buffer_index - margin);
                                         if (receive_size == 0)
                                         {
                                                 break;
@@ -387,8 +366,8 @@ private:
                                 }
                                 http_receive_buffer_[receive_buffer_index] = '\0';
                         }
+                        close(socket_fd);
                 }
-                close(socket_fd);
                 return result;
         }
 
@@ -687,6 +666,7 @@ private:
         }
 
 private:
+        SkkSocket skk_socket_;
         int work_a_buffer_size_;
         int work_b_buffer_size_;
         int http_send_buffer_size_;
